pub fn process_changes(
config: &OkcConfig,
changes: &FileChanges,
known_paths: &[String],
) -> (Vec<ParsedDocument>, ProcessChangesResult)Expand description
Process file changes and return parsed documents ready for storage.
pub fn process_changes(
config: &OkcConfig,
changes: &FileChanges,
known_paths: &[String],
) -> (Vec<ParsedDocument>, ProcessChangesResult)Process file changes and return parsed documents ready for storage.