Module document

Module document 

Document model for the Open Knowledge Catalog.

This module provides the core data structures for representing documents, their metadata, search results, validation, and statistics.

Re-exports

pub use content::CodeBlock;
pub use content::Heading;
pub use content::HeadingInfo;
pub use content::LinkInfo;
pub use content::ParsedDocument;
pub use content::Section;
pub use content::Table;
pub use content::TableAlignment;
pub use frontmatter::FrontMatter;
pub use frontmatter::LimitError;
pub use frontmatter::ParseError;
pub use frontmatter::ParseStatus;
pub use records::BacklinkInfo;
pub use records::DocumentDetail;
pub use records::DocumentMetadata;
pub use records::DocumentSummary;
pub use records::FileRecord;
pub use search::derive_display_title;
pub use search::MetadataQueryResponse;
pub use search::SearchResponse;
pub use search::SearchResult;
pub use stats::IndexStats;
pub use stats::LimitError as StatsLimitError;
pub use stats::ProcessChangesResult;
pub use stats::ScanResult;
pub use validation::CheckResult;
pub use validation::CheckStatus;
pub use validation::ValidationIssue;
pub use validation::ValidationReport;
pub use validation::ValidationSummary;

Modules

content
Document content structure types for the Open Knowledge Catalog.
frontmatter
Front-matter parsing types for the Open Knowledge Catalog.
records
Document record types for the Open Knowledge Catalog.
search
Search-related types for the Open Knowledge Catalog.
stats
Statistics types for the Open Knowledge Catalog.
validation
Validation types for the Open Knowledge Catalog.